<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro" sourcelanguage="en">
  <context>
    <name>CmdRaytracingExportProject</name>
    <message>
      <location filename="../../Command.cpp" line="522"/>
      <source>File</source>
      <translation>Fişier</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="523"/>
      <source>&amp;Export project...</source>
      <translation>&amp;Exportă proiectul...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="524"/>
      <source>Export a Raytracing project to a file</source>
      <translation>Exportați proiectul de RayLancer într-un fișier</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewLuxProject</name>
    <message>
      <location filename="../../Command.cpp" line="756"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="757"/>
      <source>New Luxrender project</source>
      <translation>Proiect Luxrender nou</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="758"/>
      <source>Insert new Luxrender project into the document</source>
      <translation>Introduceţi noul proiect de Luxrender în documentul</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="810"/>
      <source>No template</source>
      <translation>Fără șablon</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="811"/>
      <source>No template available</source>
      <translation>Niciun șablon disponibil</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPartSegment</name>
    <message>
      <location filename="../../Command.cpp" line="438"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="439"/>
      <source>Insert part</source>
      <translation>Inseraţi o componentă</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="440"/>
      <source>Insert a new part object into a Raytracing project</source>
      <translation>Insera un obiect nou Part într-un proiect de Raytracing</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPovrayProject</name>
    <message>
      <location filename="../../Command.cpp" line="321"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="322"/>
      <source>New POV-Ray project</source>
      <translation>Proiect nou de POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="323"/>
      <source>Insert new POV-Ray project into the document</source>
      <translation>Introduceţi noul proiect POV-Ray în documentul</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="375"/>
      <source>No template</source>
      <translation>Fără șablon</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="376"/>
      <source>No template available</source>
      <translation>Niciun șablon disponibil</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingRender</name>
    <message>
      <location filename="../../Command.cpp" line="589"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="590"/>
      <source>&amp;Render</source>
      <translation>&amp;Randare</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="591"/>
      <source>Renders the current raytracing project with an external renderer</source>
      <translation>Randează proiectul raytracing curent cu un renderer externe</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingResetCamera</name>
    <message>
      <location filename="../../Command.cpp" line="869"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="870"/>
      <source>&amp;Reset Camera</source>
      <translation>&amp;Reinițializare camera</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="871"/>
      <source>Sets the camera of the selected Raytracing project to match the current view</source>
      <translation>Definiți locul camerei proiectuli Raytracing selcționat pentru a se potrivi cu afișajul actual</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteCamera</name>
    <message>
      <location filename="../../Command.cpp" line="82"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Export camera to POV-Ray...</source>
      <translation>Exportă camera spre POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Export the camera position of the active 3D view in POV-Ray format to a file</source>
      <translation>Exportați poziţia camerei de vizualizare 3D activ către un fișier în format POV-Ray</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWritePart</name>
    <message>
      <location filename="../../Command.cpp" line="175"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="176"/>
      <source>Export part to POV-Ray...</source>
      <translation>Exportă piesa spre POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="177"/>
      <source>Write the selected Part (object) as a POV-Ray file</source>
      <translation>Scrie Part selectat (obiect) ca fişier POV-Ray</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteView</name>
    <message>
      <location filename="../../Command.cpp" line="98"/>
      <location filename="../../Command.cpp" line="237"/>
      <location filename="../../Command.cpp" line="337"/>
      <location filename="../../Command.cpp" line="772"/>
      <source>No perspective camera</source>
      <translation>Nici o camera cu perspectivă</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="99"/>
      <location filename="../../Command.cpp" line="238"/>
      <location filename="../../Command.cpp" line="338"/>
      <source>The current view camera is not perspective and thus resulting in a POV-Ray image that may look different than what was expected.
Do you want to continue?</source>
      <translation>Vederea actuală nu este în perspectivă, dezi rezultatul imaginii din ĂOV-Ray ar putea fi diferit de ceea ce vă așteptați. Doriți să continuați?</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Export view to POV-Ray...</source>
      <translation>Exportă vederea spre POV-Ray...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Write the active 3D view with camera and all its content to a POV-Ray file</source>
      <translation>Scrie vizualizarea 3D activ cu camera si tot conţinutul său într-un fişier de POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="352"/>
      <location filename="../../Command.cpp" line="787"/>
      <source>No template</source>
      <translation>Fără șablon</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="353"/>
      <location filename="../../Command.cpp" line="788"/>
      <source>Cannot create a project because there is no template installed.</source>
      <translation>Imposibil de creat un proiect, pentru că nu există nici un şablon instalat.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="773"/>
      <source>The current view camera is not perspective and thus resulting in a luxrender image that may look different than what was expected.
Do you want to continue?</source>
      <translation>Vederea actuală nu este în perspectivă, dezi rezultatul imaginii din Luxrender ar putea fi diferit de ceea ce vă așteptați. Doriți să continuați?</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="186"/>
      <location filename="../../Command.cpp" line="248"/>
      <location filename="../../Command.cpp" line="546"/>
      <source>POV-Ray</source>
      <translation>POV-Ray</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="136"/>
      <location filename="../../Command.cpp" line="187"/>
      <location filename="../../Command.cpp" line="249"/>
      <location filename="../../Command.cpp" line="551"/>
      <location filename="../../Command.cpp" line="665"/>
      <source>All Files</source>
      <translation>Toate fișierele</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="137"/>
      <location filename="../../Command.cpp" line="188"/>
      <location filename="../../Command.cpp" line="251"/>
      <location filename="../../Command.cpp" line="553"/>
      <source>Export page</source>
      <translation>Exportă pagina</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="450"/>
      <location filename="../../Command.cpp" line="537"/>
      <location filename="../../Command.cpp" line="605"/>
      <location filename="../../Command.cpp" line="883"/>
      <source>Wrong selection</source>
      <translation>Selecţie greşită</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="451"/>
      <source>Select a Part object.</source>
      <translation>Selecteaza un obiect tip piesă</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="461"/>
      <location filename="../../Command.cpp" line="473"/>
      <source>No Raytracing project to insert</source>
      <translation>Nici un proiect Raytracing pentru a fi inserat</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="462"/>
      <source>Create a Raytracing project to insert a view.</source>
      <translation>Crea un proiect Raytracing pentru a insera o vedere.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="474"/>
      <source>Select a Raytracing project to insert the view.</source>
      <translation>Selecționați un proiect de Raytracing pentru a vederea.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="538"/>
      <location filename="../../Command.cpp" line="606"/>
      <location filename="../../Command.cpp" line="884"/>
      <source>Select one Raytracing project object.</source>
      <translation>Selectaţi un obiect de proiect Raytracing.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="542"/>
      <source>Luxrender</source>
      <translation>Luxrender</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="621"/>
      <location filename="../../Command.cpp" line="627"/>
      <source>POV-Ray not found</source>
      <translation>POV-Ray negăsit</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="622"/>
      <source>Please set the path to the POV-Ray executable in the preferences.</source>
      <translation>Vă rugăm să definiți calea către executabilul POV-Ray în Preferinţe.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="628"/>
      <source>Please correct the path to the POV-Ray executable in the preferences.</source>
      <translation>Vă rugăm să corectaţi calea către executabil POV-Ray în Preferinţe.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="635"/>
      <location filename="../../Command.cpp" line="641"/>
      <source>Luxrender not found</source>
      <translation>Luxrender nu a fost găsit</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="636"/>
      <source>Please set the path to the luxrender or luxconsole executable in the preferences.</source>
      <translation>Vă rugăm să definiți calea către executabilul Luxrender sau Luxconsole în Preferinţe.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="642"/>
      <source>Please correct the path to the luxrender or luxconsole executable in the preferences.</source>
      <translation>Vă rugăm să corectaţi calea luxrender sau luxconsole executabil în Preferinţe.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="654"/>
      <source>POV-Ray file missing</source>
      <translation>Fișierul POV-Ray lipsește</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="655"/>
      <source>The POV-Ray project file doesn't exist.</source>
      <translation>Nu există fișier proiectului POV-Ray.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="661"/>
      <location filename="../../Command.cpp" line="663"/>
      <location filename="../../Command.cpp" line="666"/>
      <source>Rendered image</source>
      <translation>Imagine randată</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="723"/>
      <source>Lux project file missing</source>
      <translation>Fișierul de proiect Lux lipsește</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="724"/>
      <source>The Lux project file doesn't exist.</source>
      <translation>Nu există fișier proiect Lux.</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRay</name>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="14"/>
      <source>Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="26"/>
      <source>Mesh export settings</source>
      <translation>Setari de export pentru Retele</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="52"/>
      <source>Max mesh deviation:</source>
      <translation>Deviere maximă a plasei:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="80"/>
      <source>Do not calculate vertex normals</source>
      <translation>Nu calcula normalele pentru vertex-uri</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="93"/>
      <source>Write u,v coordinates</source>
      <translation>Scrie coordonatele u,v</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="109"/>
      <source>Render</source>
      <translation>Randare</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="127"/>
      <source>POV-Ray executable:</source>
      <translation>POV-Ray executabil:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="134"/>
      <source>POV-Ray output parameters:</source>
      <translation>POV-Ray parametrii de ieşire:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="143"/>
      <source>The POV-Ray parameters to be passed to the render.</source>
      <translation>Parametrii POV-Ray vor fi trecuți la randare.</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="146"/>
      <source>+P +A</source>
      <translation>+ P + A</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="159"/>
      <source>+W: </source>
      <translation>+W: : </translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="166"/>
      <source>The width of the rendered image</source>
      <translation>Lăţimea imaginii randate</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="185"/>
      <source> +H : </source>
      <translation> +H : </translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="192"/>
      <source>The height of the rendered image</source>
      <translation>Înălţimea de imaginea randată</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="213"/>
      <source>Luxrender executable:</source>
      <translation>Executabilul Luxrender:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="220"/>
      <source>The path to the luxrender (or luxconsole) executable</source>
      <translation>Calea către executabilul Luxrender (sau Luxconsole)</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="238"/>
      <source>Directories</source>
      <translation>Directoare</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="258"/>
      <source>Part file name:</source>
      <translation>Numele fişierului pentru componentă:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="265"/>
      <source>Camera file name:</source>
      <translation>Numele fişierului camerei:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="275"/>
      <location filename="../../DlgSettingsRay.ui" line="298"/>
      <location filename="../../DlgSettingsRay.ui" line="314"/>
      <source>Used by utility tools</source>
      <translation>Folosit de instrumentele utilitarului</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="291"/>
      <source>Default Project dir:</source>
      <translation>Directorul implicit al proiectului:</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="301"/>
      <source>TempCamera.inc</source>
      <translation>TempCamera.inc</translation>
    </message>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="317"/>
      <source>TempPart.inc</source>
      <translation>TempPart.inc</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRayImp</name>
    <message>
      <location filename="../../DlgSettingsRayImp.cpp" line="47"/>
      <source>The path to the POV-Ray executable, if you want to render from %1</source>
      <translation>Calea către executabilul POV-Ray, dacă doriți să faceți render de la %1</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::ViewProviderLux</name>
    <message>
      <location filename="../../ViewProvider.cpp" line="68"/>
      <source>Edit LuxRender project</source>
      <translation>Editați proiectul LuxRender</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="99"/>
      <source>LuxRender template</source>
      <translation>LuxRender şablon</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="99"/>
      <source>Select a LuxRender template</source>
      <translation>Selectați un șablon de LuxRender</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::ViewProviderPovray</name>
    <message>
      <location filename="../../ViewProvider.cpp" line="147"/>
      <source>Edit Povray project</source>
      <translation>Editați Povray proiect</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="178"/>
      <source>Povray template</source>
      <translation>Povray şablon</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="178"/>
      <source>Select a Povray template</source>
      <translation>Selectaţi un şablon de Povray</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
  </context>
</TS>
